@@ -22,16 +22,9 @@ class TestCrawler < Test::Unit::TestCase
 
   def test_exactsearch2
     crawler = Cassiopee::Crawler.new
-    crawler.setLogLevel(Logger::DEBUG)
     crawler.indexString('my sample example')
     matches = crawler.searchExact('xample')
     assert_equal(1,matches.length)
-    # Minus 1, because first element is len of match
-    match = crawler.next()
-    puts "## "+match.to_s
-    #assert_equal(2,match[2].length-1)
-    crawler.setLogLevel(Logger::ERROR)
-
   end
 
 
@@ -58,6 +51,16 @@ class TestCrawler < Test::Unit::TestCase
     assert_equal(1,matches.length)
   end
 
+  def test_levenshteinsearch2
+    crawler = Cassiopee::Crawler.new
+    crawler.indexString('aaaaacgtttttt')
+    matches = crawler.searchApproximate('ac',-2)
+    matches.each do |match|
+      puts match.to_s 
+    end
+    assert_equal(1,matches.length)
+  end
+
   def test_directmethod
     crawler = Cassiopee::Crawler.new
     crawler.method = Cassiopee::Crawler::METHOD_DIRECT
